package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ScoreRoomUser;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2025-10-30
 */
public interface ScoreRoomUserMapper
{
    /**
     * 查询【请填写功能名称】
     *
     * @param roomUserId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public ScoreRoomUser selectScoreRoomUserByRoomUserId(Long roomUserId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param scoreRoomUser 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<ScoreRoomUser> selectScoreRoomUserList(ScoreRoomUser scoreRoomUser);

    /**
     * 新增【请填写功能名称】
     *
     * @param scoreRoomUser 【请填写功能名称】
     * @return 结果
     */
    public int insertScoreRoomUser(ScoreRoomUser scoreRoomUser);

    /**
     * 修改【请填写功能名称】
     *
     * @param scoreRoomUser 【请填写功能名称】
     * @return 结果
     */
    public int updateScoreRoomUser(ScoreRoomUser scoreRoomUser);

    /**
     * 删除【请填写功能名称】
     *
     * @param roomUserId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteScoreRoomUserByRoomUserId(Long roomUserId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param roomUserIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScoreRoomUserByRoomUserIds(Long[] roomUserIds);
}
