package com.ruoyi.web.controller.scoring;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ScoreRoomUser;
import com.ruoyi.system.service.IScoreRoomUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-10-30
 */
@RestController
@RequestMapping("/system/score/room/user")
public class ScoreRoomUserController extends BaseController
{
    @Autowired
    private IScoreRoomUserService scoreRoomUserService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(ScoreRoomUser scoreRoomUser)
    {
        startPage();
        List<ScoreRoomUser> list = scoreRoomUserService.selectScoreRoomUserList(scoreRoomUser);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:user:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScoreRoomUser scoreRoomUser)
    {
        List<ScoreRoomUser> list = scoreRoomUserService.selectScoreRoomUserList(scoreRoomUser);
        ExcelUtil<ScoreRoomUser> util = new ExcelUtil<ScoreRoomUser>(ScoreRoomUser.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:user:query')")
    @GetMapping(value = "/{roomUserId}")
    public AjaxResult getInfo(@PathVariable("roomUserId") Long roomUserId)
    {
        return success(scoreRoomUserService.selectScoreRoomUserByRoomUserId(roomUserId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ScoreRoomUser scoreRoomUser)
    {
        return toAjax(scoreRoomUserService.insertScoreRoomUser(scoreRoomUser));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ScoreRoomUser scoreRoomUser)
    {
        return toAjax(scoreRoomUserService.updateScoreRoomUser(scoreRoomUser));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:user:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{roomUserIds}")
    public AjaxResult remove(@PathVariable Long[] roomUserIds)
    {
        return toAjax(scoreRoomUserService.deleteScoreRoomUserByRoomUserIds(roomUserIds));
    }
}
